@@ -1,8 +1,10 @@
-# Copyright (C) 2003-2005, G. Allen Morris III, all rights reserved
+# Copyright (C) 2003-2007, G. Allen Morris III, all rights reserved
 
 use strict;
 
-package Data::Tabular::Row::Extra;
+package
+    Data::Tabular::Row::Extra;
+
 use base 'Data::Tabular::Row';
 
 use Carp qw (croak);
