@@ -1,9 +1,10 @@
-# Copyright (C) 2003-2005, G. Allen Morris III, all rights reserved
+# Copyright (C) 2003-2007, G. Allen Morris III, all rights reserved
 
 use strict;
-package Data::Tabular::Row::Header;
+package
+    Data::Tabular::Row::Header;
 
-use base 'Data::Tabular::Row::Group';
+use base 'Data::Tabular::Row';
 
 use Carp qw(croak);
 
@@ -69,11 +70,6 @@ sub type
     'header';
 }
 
-sub is_header
-{
-    1;
-}
-
 1;
 __END__
 
